========================================
The Hierarchical Data Modeling Framework
========================================

The Hierarchical Data Modeling Framework, or *HDMF*, is a Python package for working with hierarchical data.
It provides APIs for specifying data models, reading and writing data to different storage backends, and
representing data with Python object.

Documentation of HDMF can be found at https://hdmf.readthedocs.io

Latest Release
==============

.. image:: https://badge.fury.io/py/hdmf.svg
     :target: https://badge.fury.io/py/hdmf

.. image:: https://anaconda.org/conda-forge/hdmf/badges/version.svg
     :target: https://anaconda.org/conda-forge/hdmf


Build Status
============

.. table::

  +---------------------------------------------------------------------+--------------------------------------------------------------------------------------------------+
  | Linux                                                               | Windows and macOS                                                                                |
  +=====================================================================+==================================================================================================+
  | .. image:: https://circleci.com/gh/hdmf-dev/hdmf.svg?style=shield   | .. image:: https://dev.azure.com/hdmf-dev/hdmf/_apis/build/status/hdmf-dev.hdmf?branchName=dev   |
  |     :target: https://circleci.com/gh/hdmf-dev/hdmf                  |     :target: https://dev.azure.com/hdmf-dev/hdmf/_build/latest?definitionId=1&branchName=dev     |
  +---------------------------------------------------------------------+--------------------------------------------------------------------------------------------------+


**Conda**

.. image:: https://circleci.com/gh/conda-forge/hdmf-feedstock.svg?style=shield
     :target: https://circleci.com/gh/conda-forge/hdmf-feedstock


Overall Health
==============

.. image:: https://codecov.io/gh/hdmf-dev/hdmf/branch/dev/graph/badge.svg
    :target: https://codecov.io/gh/hdmf-dev/hdmf

.. image:: https://requires.io/github/hdmf-dev/hdmf/requirements.svg?branch=dev
     :target: https://requires.io/github/hdmf-dev/hdmf/requirements/?branch=dev
     :alt: Requirements Status

.. image:: https://readthedocs.org/projects/hdmf/badge/?version=latest
     :target: https://hdmf.readthedocs.io/en/latest/?badge=latest
     :alt: Documentation Status

Installation
============

See the HDMF documentation for details http://hdmf.readthedocs.io/en/latest/getting_started.html#installation

Code of Conduct
===============

This project and everyone participating in it is governed by our `code of conduct guidelines <.github/CODE_OF_CONDUCT.md>`_. By participating, you are expected to uphold this code.

Contributing
============

For details on how to contribute to HDMF see our `contribution guidelines <docs/CONTRIBUTING.rst>`_.

LICENSE
=======

"hdmf" Copyright (c) 2017-2020, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from the U.S. Dept. of Energy).  All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

(1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

(2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

(3) Neither the name of the University of California, Lawrence Berkeley National Laboratory, U.S. Dept. of Energy nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

You are under no obligation whatsoever to provide any bug fixes, patches, or upgrades to the features, functionality or performance of the source code ("Enhancements") to anyone; however, if you choose to make your Enhancements available either publicly, or directly to Lawrence Berkeley National Laboratory, without imposing a separate written license agreement for such Enhancements, then you hereby grant the following license: a  non-exclusive, royalty-free perpetual license to install, use, modify, prepare derivative works, incorporate into other computer software, distribute, and sublicense such enhancements or derivative works thereof, in binary and source code form.

COPYRIGHT
=========

"hdmf" Copyright (c) 2017-2020, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from the U.S. Dept. of Energy).  All rights reserved.
If you have questions about your rights to use or distribute this software, please contact Berkeley Lab's Innovation & Partnerships Office at IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department of Energy and the U.S. Government consequently retains certain rights. As such, the U.S. Government has been granted for itself and others acting on its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the Software to reproduce, distribute copies to the public, prepare derivative works, and perform publicly and display publicly, and to permit other to do so.
